replace_ranges

Function replace_ranges 

pub fn replace_ranges(text: &str, ranges: &[Range<usize>], with: &str) -> String
A text with some ranges of it, counted in characters and not overlapping, replaced by another text.