run

Function run 

pub fn run<V: View + 'static>(
    product: Product,
    build: impl FnOnce(&Context) -> V + 'static,
) -> Result
Open a window for a product, with the paths given on the command line.

Errors

The window could not be created, which is eframe’s answer and not this application’s.