pub struct FindBar { /* private fields */ }Expand description
The state of the search bar.
Implementations
Sourceimpl FindBar
impl FindBar
Sourcepub fn open_replacing(&mut self)
pub fn open_replacing(&mut self)
Show the bar and put the keyboard in the replacement, where there is a query to replace.
Sourcepub fn replacement(&self) -> &str
pub fn replacement(&self) -> &str
What replaces a match.