pub fn link_format(
properties: &TextProperties,
inherited: f32,
zoom: f32,
palette: Palette,
) -> TextFormatExpand description
The same, for a run the document marks as a hyperlink.
pub fn link_format(
properties: &TextProperties,
inherited: f32,
zoom: f32,
palette: Palette,
) -> TextFormatThe same, for a run the document marks as a hyperlink.